==> yauaa-1.4-sources.jar: nl/basjes/parse/useragent/utils/AntlrUtils.java <==
/*
 * Yet Another UserAgent Analyzer
 * Copyright (C) 2013-2017 Niels Basjes
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.basjes.parse.useragent.utils;

import org.antlr.v4.runtime.CharStream;
import org.antlr.v4.runtime.ParserRuleContext;
import org.antlr.v4.runtime.misc.Interval;
import org.antlr.v4.runtime.tree.ParseTree;
import org.antlr.v4.runtime.tree.RuleNode;

public final class AntlrUtils {
    private AntlrUtils() {
    }

    public static String getSourceText(ParserRuleContext ctx){
        if (ctx.start == null) {
            return null; // Invalid
        }
        if (ctx.stop == null) {
            return ctx.getText();
        }
        int startIndex = ctx.start.getStartIndex();
        int stopIndex = ctx.stop.getStopIndex();
        if (stopIndex < startIndex) {
            return ctx.getText();
        }
        CharStream inputStream = ctx.start.getInputStream();
        return inputStream.getText(new Interval(startIndex, stopIndex));
    }

    public static String getSourceText(RuleNode ruleNode){
        if (ruleNode instanceof ParserRuleContext) {
            return getSourceText((ParserRuleContext)ruleNode);
        }
        return ruleNode.getText();
    }

    public static String getSourceText(ParseTree ruleNode){
        if (ruleNode instanceof ParserRuleContext) {
            return getSourceText((ParserRuleContext)ruleNode);
        }
        return ruleNode.getText();
    }

}

==> yauaa-6.4-sources.jar: nl/basjes/parse/useragent/utils/AntlrUtils.java <==
/*
 * Yet Another UserAgent Analyzer
 * Copyright (C) 2013-2021 Niels Basjes
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.basjes.parse.useragent.utils;

import org.antlr.v4.runtime.CharStream;
import org.antlr.v4.runtime.ParserRuleContext;
import org.antlr.v4.runtime.misc.Interval;
import org.antlr.v4.runtime.tree.ParseTree;

public final class AntlrUtils {
    private AntlrUtils() {}

    public static final ParseTree NULL_PARSE_TREE = new ParserRuleContext() {
        @Override
        public String getText() {
            return null;
        }
    };

    public static String getSourceText(ParserRuleContext ctx){
        if (ctx == null) {
            return null;
        }
        if (ctx.start == null || ctx.stop == null) {
            return ctx.getText();
        }
        int startIndex = ctx.start.getStartIndex();
        int stopIndex = ctx.stop.getStopIndex();
        if (stopIndex < startIndex) {
            return ""; // Just return the empty string.
        }
        CharStream inputStream = ctx.start.getInputStream();
        return inputStream.getText(new Interval(startIndex, stopIndex));
    }

}
